use crate::{entity::account, utils::handle_master_password_check};
use sea_orm::prelude::*;
use teloxide::{adaptors::Throttle, prelude::*};

pub async fn add_account(
    bot: Throttle<Bot>,
    msg: Message,
    db: DatabaseConnection,
    (name, login, password, master_pass): (String, String, String, String),
) -> crate::Result<()> {
    let user_id = msg.from().unwrap().id.0;
    if handle_master_password_check(&bot, &db, msg.chat.id, user_id, &master_pass).await? {
        return Ok(());
    };
    let account =
        account::ActiveModel::from_unencrypted(user_id, name, &login, &password, &master_pass)?;
    account.insert(&db).await?;
    bot.send_message(msg.chat.id, "Success").await?;
    Ok(())
}
