use crate::{
    entity::{account, prelude::Account},
    utils::handle_master_password_check,
};
use sea_orm::prelude::*;
use teloxide::{adaptors::Throttle, prelude::*, types::ParseMode};

pub async fn get_account(
    bot: Throttle<Bot>,
    msg: Message,
    db: DatabaseConnection,
    (name, master_pass): (String, String),
) -> crate::Result<()> {
    let user_id = msg.from().unwrap().id.0;
    if handle_master_password_check(&bot, &db, msg.chat.id, user_id, &master_pass).await? {
        return Ok(());
    };
    let account = Account::find()
        .filter(
            account::Column::UserId
                .eq(user_id)
                .add(account::Column::Name.eq(&name)),
        )
        .one(&db)
        .await?
        .unwrap();
    let (login, password) = account.decrypt(&master_pass)?;
    let message = format!("Name:\n`{name}`\nLogin:\n`{login}`\nPassword:\n`{password}`");
    bot.send_message(msg.chat.id, message)
        .parse_mode(ParseMode::MarkdownV2)
        .await?;
    Ok(())
}
