use crate::entity::{master_pass, prelude::*};
use sea_orm::{prelude::*, QuerySelect};
use teloxide::{adaptors::Throttle, prelude::*};
use tokio::task;

pub async fn set_master_pass(
    bot: Throttle<Bot>,
    msg: Message,
    db: DatabaseConnection,
    master_pass: String,
) -> crate::Result<()> {
    let user_id = msg.from().unwrap().id.0;
    let exists = MasterPass::find()
        .select_only()
        .column(master_pass::Column::UserId)
        .filter(master_pass::Column::UserId.eq(user_id))
        .into_tuple::<u64>()
        .one(&db)
        .await?
        .is_some();
    if exists {
        bot.send_message(msg.chat.id, "Master password already exists")
            .await?;
        return Ok(());
    }
    let model = task::spawn_blocking(move || {
        master_pass::ActiveModel::from_unencrypted(user_id, &master_pass)
    })
    .await??;
    model.insert(&db).await?;
    bot.send_message(msg.chat.id, "Success").await?;
    Ok(())
}
